@@ -16,7 +16,7 @@ use std::time::Duration;
 use tokio::sync::Notify;
 use tokio::time::sleep;
 
-const DEFAULT_ID_LISTS_MANIFEST_URL: &str = "https://statsigapi.net/v1/get_id_lists";
+const DEFAULT_CDN_ID_LISTS_MANIFEST_URL: &str = "https://api.statsigcdn.com/v1/get_id_lists";
 const DEFAULT_ID_LIST_SYNC_INTERVAL_MS: u32 = 10_000;
 
 type IdListsResponse = HashMap<String, IdListMetadata>;
@@ -36,19 +36,18 @@ pub struct StatsigHttpIdListsAdapter {
 impl StatsigHttpIdListsAdapter {
     #[must_use]
     pub fn new(sdk_key: &str, options: &StatsigOptions) -> Self {
-        let id_lists_manifest_url = options
-            .id_lists_url
-            .clone()
-            .unwrap_or_else(|| DEFAULT_ID_LISTS_MANIFEST_URL.to_string());
-
-        let fallback_url = if options.fallback_to_statsig_api.unwrap_or(false)
-            && id_lists_manifest_url != DEFAULT_ID_LISTS_MANIFEST_URL
-        {
-            Some(DEFAULT_ID_LISTS_MANIFEST_URL.to_string())
-        } else {
-            None
+        let id_lists_manifest_url = match &options.id_lists_url {
+            Some(url) => url.clone(),
+            None => make_default_cdn_url(sdk_key),
         };
 
+        let mut fallback_url = None;
+        if options.fallback_to_statsig_api == Some(true)
+            && !id_lists_manifest_url.contains(DEFAULT_CDN_ID_LISTS_MANIFEST_URL)
+        {
+            fallback_url = Some(make_default_cdn_url(sdk_key));
+        }
+
         let sync_interval_duration = Duration::from_millis(u64::from(
             options
                 .id_lists_sync_interval_ms
@@ -80,9 +79,16 @@ impl StatsigHttpIdListsAdapter {
             ..RequestArgs::new()
         };
 
-        let initial_err = match self.network.post(request_args.clone(), None).await {
-            Ok(response) => return self.parse_response(response.data),
-            Err(e) => e,
+        let initial_err = if self.is_cdn_url() {
+            match self.network.get(request_args.clone()).await {
+                Ok(response) => return self.parse_response(response.data),
+                Err(e) => e,
+            }
+        } else {
+            match self.network.post(request_args.clone(), None).await {
+                Ok(response) => return self.parse_response(response.data),
+                Err(e) => e,
+            }
         };
 
         if initial_err != NetworkError::RetriesExhausted {
@@ -150,7 +156,8 @@ impl StatsigHttpIdListsAdapter {
 
         // TODO add log
 
-        match self.network.post(request_args.clone(), None).await {
+        // fallback to cdn, it's a get request
+        match self.network.get(request_args.clone()).await {
             Ok(response) => Ok(response),
             Err(e) => {
                 let msg = format!("Fallback request failed: {e:?}");
@@ -178,6 +185,11 @@ impl StatsigHttpIdListsAdapter {
         );
     }
 
+    fn is_cdn_url(&self) -> bool {
+        self.id_lists_manifest_url
+            .starts_with(DEFAULT_CDN_ID_LISTS_MANIFEST_URL)
+    }
+
     fn parse_response(&self, response: Option<Vec<u8>>) -> Result<IdListsResponse, StatsigErr> {
         let response = match response.filter(|r| !r.is_empty()) {
             Some(r) => r,
@@ -379,6 +391,10 @@ impl IdListsAdapter for StatsigHttpIdListsAdapter {
     }
 }
 
+fn make_default_cdn_url(sdk_key: &str) -> String {
+    format!("{}/{}.json", DEFAULT_CDN_ID_LISTS_MANIFEST_URL, sdk_key)
+}
+
 #[cfg(test)]
 mod tests {
     use crate::hashing::HashUtil;
